import babel from "@rollup/plugin-babel";
import resolve from "@rollup/plugin-node-resolve";
import commonjs from "@rollup/plugin-commonjs";
import typescript from "@rollup/plugin-typescript";
import json from "@rollup/plugin-json";
import css from "rollup-plugin-import-css";

export default {
  input: "src/index.ts", // Entry point
  output: [
    {
      file: "dist/index.cjs.js",
      format: "cjs", // CommonJS format
      exports: "named",
    },
    {
      file: "dist/index.esm.js",
      format: "esm", // ES module format
    },
  ],
  external: ["react", "react-dom"], // Mark peer dependencies as external
  plugins: [
    resolve(), // Resolves node_modules
    commonjs(), // Converts CommonJS to ES modules
    babel({
      babelHelpers: "bundled",
      extensions: [".ts", ".tsx", ".js", ".jsx"], // Enable TypeScript and JSX
      exclude: "node_modules/**",
    }),
    typescript({
      tsconfig: "./tsconfig.json",
      declaration: true,
      declarationDir: "dist",
    }),
    json(),
    css(),
  ],
};
